@@ -156,9 +156,9 @@ from kivymd import images_path, uix_path
 from kivymd.theming import ThemableBehavior
 from kivymd.uix.behaviors import CircularRippleBehavior
 from kivymd.uix.boxlayout import MDBoxLayout
-from kivymd.uix.list import BaseListItem, ContainerSupport
+from kivymd.uix.fitimage import FitImage
+from kivymd.uix.list import BaseListItem
 from kivymd.uix.relativelayout import MDRelativeLayout
-from kivymd.utils.fitimage import FitImage
 
 with open(
     os.path.join(uix_path, "filemanager", "filemanager.kv"), encoding="utf-8"
@@ -182,13 +182,20 @@ class IconButton(CircularRippleBehavior, ButtonBehavior, FitImage):
     """Folder icons/thumbnails images in ``preview`` mode."""
 
 
-class FloatButton(AnchorLayout):
+class FloatButton(ThemableBehavior, AnchorLayout):
     callback = ObjectProperty()
     md_bg_color = ColorProperty([1, 1, 1, 1])
     icon = StringProperty()
 
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.theme_cls.bind(primary_palette=self.set_md_bg_color)
 
-class ModifiedOneLineIconListItem(ContainerSupport, BaseListItem):
+    def set_md_bg_color(self, *args):
+        self.md_bg_color = self.theme_cls.primary_color
+
+
+class ModifiedOneLineIconListItem(BaseListItem):
     _txt_left_pad = NumericProperty("72dp")
     _txt_top_pad = NumericProperty("16dp")
     _txt_bot_pad = NumericProperty("15dp")
