@@ -274,7 +274,7 @@ Clickable icon for MDTextField
     See more information in the :class:`~MDTextFieldRect` class.
 """
 
-__all__ = ("MDTextField", "MDTextFieldRect", "MDTextFieldRound")
+__all__ = ("MDTextField", "MDTextFieldRect")
 
 import os
 import re
@@ -302,6 +302,7 @@ from kivy.uix.textinput import TextInput
 from kivymd import uix_path
 from kivymd.font_definitions import theme_font_styles
 from kivymd.theming import ThemableBehavior
+from kivymd.uix.behaviors import DeclarativeBehavior
 from kivymd.uix.label import MDIcon
 
 with open(
@@ -382,7 +383,7 @@ class TextfieldLabel(ThemableBehavior, Label):
         self.font_size = sp(self.theme_cls.font_styles[self.font_style][1])
 
 
-class MDTextField(ThemableBehavior, TextInput):
+class MDTextField(DeclarativeBehavior, ThemableBehavior, TextInput):
     helper_text = StringProperty()
     """
     Text for ``helper_text`` mode.
@@ -418,20 +419,6 @@ class MDTextField(ThemableBehavior, TextInput):
     and defaults to `False`.
     """
 
-    color_mode = OptionProperty(
-        "primary", options=["primary", "accent", "custom"], deprecated=True
-    )
-    """
-    Color text mode. Available options are: `'primary'`, `'accent'`,
-    `'custom'`.
-
-    .. deprecated:: 1.0.0
-        Don't use this attribute.
-
-    :attr:`color_mode` is an :class:`~kivy.properties.OptionProperty`
-    and defaults to `'primary'`.
-    """
-
     mode = OptionProperty(
         "line", options=["rectangle", "round", "fill", "line"]
     )
@@ -493,18 +480,6 @@ class MDTextField(ThemableBehavior, TextInput):
     and defaults to `[0, 0, 0, 0]`.
     """
 
-    fill_color = ColorProperty([0, 0, 0, 0], deprecated=True)
-    """
-    The background color of the fill in rgba format when the ``mode`` parameter
-    is "fill".
-
-    .. deprecated:: 1.0.0
-        Use :attr:`fill_color_normal` and :attr:`fill_color_focus` instead.
-
-    :attr:`fill_color` is an :class:`~kivy.properties.ColorProperty`
-    and defaults to `[0, 0, 0, 0]`.
-    """
-
     fill_color_normal = ColorProperty([0, 0, 0, 0])
     """
     Fill background color in 'fill' mode when text field is out of focus.
@@ -537,17 +512,6 @@ class MDTextField(ThemableBehavior, TextInput):
     and defaults to `False`.
     """
 
-    current_hint_text_color = ColorProperty([0, 0, 0, 0], deprecated=True)
-    """
-    Hint text color.
-
-    .. deprecated:: 1.0.0
-        Use :attr:`hint_text_color_normal` and :attr:`hint_text_color_focus` instead.
-
-    :attr:`current_hint_text_color` is an :class:`~kivy.properties.ColorProperty`
-    and defaults to `[0, 0, 0, 0]`.
-    """
-
     hint_text_color_normal = ColorProperty([0, 0, 0, 0])
     """
     Hint text color when text field is out of focus.
@@ -752,28 +716,6 @@ class MDTextField(ThemableBehavior, TextInput):
     and defaults to `''`.
     """
 
-    icon_right_color = ColorProperty([0, 0, 0, 1], deprecated=True)
-    """
-    Color of right icon in ``rgba`` format.
-
-    .. deprecated:: 1.0.0
-        Don't use this attribute.
-
-    :attr:`icon_right_color` is an :class:`~kivy.properties.ColorProperty`
-    and defaults to `[0, 0, 0, 1]`.
-    """
-
-    text_color = ColorProperty([0, 0, 0, 0], deprecated=True)
-    """
-    Text color in ``rgba`` format.
-
-    .. deprecated:: 1.0.0
-        Use :attr:`text_color_normal` and :attr:`text_color_focus` instead.
-
-    :attr:`text_color` is an :class:`~kivy.properties.ColorProperty`
-    and defaults to `[0, 0, 0, 0]`.
-    """
-
     text_color_normal = ColorProperty([0, 0, 0, 0])
     """
     Text color in ``rgba`` format when text field is out of focus.
@@ -924,12 +866,12 @@ class MDTextField(ThemableBehavior, TextInput):
     # application color palette.
     _colors_to_updated = ListProperty()
 
-    def __init__(self, **kwargs):
+    def __init__(self, *args, **kwargs):
         self.set_objects_labels()
         Clock.schedule_once(self._set_attr_names_to_updated)
         Clock.schedule_once(self.set_colors_to_updated)
         Clock.schedule_once(self.set_default_colors)
-        super().__init__(**kwargs)
+        super().__init__(*args, **kwargs)
         self.bind(
             _hint_text_font_size=self._hint_text_label.setter("font_size"),
             _icon_right_color=self._icon_right_label.setter("text_color"),
@@ -1015,12 +957,12 @@ class MDTextField(ThemableBehavior, TextInput):
 
         def on_progress(*args):
             self._line_blank_space_right_point = (
-                self._hint_text_label.width + dp(5) if not joining else 0
+                self._hint_text_label.width + dp(17) if not joining else 0
             )
 
         if self.hint_text:
             animation = Animation(
-                _line_blank_space_left_point=self._hint_text_label.x - dp(5)
+                _line_blank_space_left_point=self._hint_text_label.x - dp(-7)
                 if not joining
                 else 0,
                 duration=0.2,
@@ -1103,7 +1045,7 @@ class MDTextField(ThemableBehavior, TextInput):
                 t="out_quad",
             ).start(self)
 
-    def set_pos_hint_text(self, y: float, x: float = 0) -> None:
+    def set_pos_hint_text(self, y: float, x: float = 12) -> None:
         """Animates the x-axis width and y-axis height of the hint text."""
 
         if self.mode != "round":
@@ -1113,7 +1055,7 @@ class MDTextField(ThemableBehavior, TextInput):
                     _hint_x = x
                 else:
                     if y == dp(10):
-                        _hint_x = dp(-16)
+                        _hint_x = dp(-4)
                     else:
                         _hint_x = dp(20)
 
@@ -1424,21 +1366,6 @@ class MDTextField(ThemableBehavior, TextInput):
         """Method override to avoid duplicate hint text texture."""
 
 
-class MDTextFieldRound(MDTextField):
-    """
-    .. deprecated:: 1.0.0
-        Use :class:`~MDTextField` class instead.
-    """
-
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-        Logger.warning(
-            "KivyMD: "
-            "The `MDTextFieldRound` class has been deprecated. "
-            "Use the `MDTextField` class instead with `mode='round'`"
-        )
-
-
 if __name__ == "__main__":
     from kivy.lang import Builder
     from kivy.uix.textinput import TextInput
